import * as ec2 from '@aws-cdk/aws-ec2';
import * as ecs from '@aws-cdk/aws-ecs';
import * as sns from '@aws-cdk/aws-sns';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface FargateFastAutoscalerProps {
    /**
     * The VPC for the stack.
     *
     * @stability stable
     */
    readonly vpc: ec2.IVpc;
    /**
     * SNS Topic to publish the notification.
     *
     * @default - do not publish to SNS
     * @stability stable
     */
    readonly snsTopic?: sns.ITopic;
    /**
     * AWS CLI Lambda layer ARN in Serverless App Repository.
     *
     * @default - 'arn:aws:serverlessrepo:us-east-1:903779448426:applications/lambda-layer-awscli'
     * @stability stable
     */
    readonly awsCliLayerArn?: string;
    /**
     * The version of the Serverless App for AWS CLI Lambda layer.
     *
     * @default - AWSCLI_LAYER_VERSION
     * @stability stable
     */
    readonly awsCliLayerVersion?: string;
    /**
     * backend container.
     *
     * @stability stable
     */
    readonly backendContainer: ecs.ContainerDefinitionOptions;
    /**
     * container port for the backend container.
     *
     * @stability stable
     */
    readonly backendContainerPortMapping: ecs.PortMapping[];
    /**
     * initial number of tasks for the service.
     *
     * @default - 2
     * @stability stable
     */
    readonly initialTaskNumber?: number;
    /**
     * disable scale in.
     *
     * @default - true
     * @stability stable
     */
    readonly disableScaleIn?: boolean;
}
/**
 * @stability stable
 */
export declare class FargateFastAutoscaler extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly fargateWatcherFuncArn: string;
    /**
     * @stability stable
     */
    readonly layerVersionArn: string;
    /**
     * @stability stable
     */
    readonly fargateService: ecs.FargateService;
    /**
     * @stability stable
     */
    readonly fargateTaskDef: ecs.FargateTaskDefinition;
    /**
     * @stability stable
     */
    readonly vpc: ec2.IVpc;
    /**
     * @stability stable
     */
    readonly region: string;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: FargateFastAutoscalerProps);
}
